@@ -582,8 +582,9 @@ def file_delete(file_path):
         try:
             os.remove(file_path)
         except OSError as e:
-            if e.errno != errno.ENOENT:
-                raise
+            print("Error Code '{0}', {1}".format(type(e).__name__, str(e)))
+
+            pass
 
 
 def file_move(from_file_path, to_file_path, migrate=False):
