@@ -100,7 +100,8 @@ class LogHandle(object):
                                 level=logging.DEBUG, format=' %(asctime)s - %(levelname)s - %(message)s')
 
         if self.__gui_console:
-            self.__gui_console.print_gui('{0} - {1} - {2}'.format(datetime.now(), action.upper(), message))
+            self.__gui_console.print_gui('{0} - {1} - {2}'.format(datetime.now().__format__("%Y%m%d %I:%M:%S %p"),
+                                                                  action.upper(), message))
         else:
             print('{0} - {1} - {2}'.format(datetime.now(), action.upper(), message))
 
@@ -156,8 +157,14 @@ class GUIConsole(Toplevel):
         my_frame = Frame(self)
         my_frame.pack()
 
-        self.__console_text = Text(my_frame, bg="black", fg="white")
-        self.__console_text.pack()
+        xbar = Scrollbar(my_frame, orient='horizontal')
+        ybar = Scrollbar(my_frame, orient='vertical')
+        self.__console_text = Text(my_frame, bg="black", fg="white", yscrollcommand=ybar, xscrollcommand=xbar)
+        xbar.config(command=self.__console_text.xview)
+        ybar.config(command=self.__console_text.yview)
+        self.__console_text.grid(row=0, column=0)
+        xbar.grid(row=1, column=0, sticky=W + E)
+        ybar.grid(row=0, column=1, sticky=N + S)
 
     def __on_idle(self):
         with self.__print_lock:
